# __init__.py
#from . import *
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
start=sj.now()
from pdsystem import *