#log.py
#准备一年，更新更新，优化，优化
#2021.7.16 #项目上传
# 即将更新log:1把每个判断放到input下面2print ('{} '.format(j))3.过多的无效代码行
# 优化部分显示
#增加自述文件
#############
#ver2.5.4.1
#修复一个小bug
#ver2.6.1
'''修复一个print,2.6是为了方便打包改的
优化beginning文件，但无改动'''

#原模块为3y现在更名为a_3y
#----------ycc------------
#更名 ycc
#支持命令行运行了
#修复eval,bug
#版本号更改
#自述文件更新
#keywords修改
#----------ycc0.3.2--------
#setup 修改,依赖包修改
#修改配置文件
#-----------ycc0.3.8--------
#美化在pypi上的显示
#-----------ycc0.4-----------
#修复因意外导致的bug
#优化一下显示 2020.8.1
#-----------sycc(定制版)
#正式开通
#即将y,yz更新，try,except,print(done!)
#程序名字改新名，但下载方式与链接不变